@@ -13,6 +13,7 @@ from avro2py.avro_types import (
     Primitives, LogicalTypes, Record, AvroPrimitives, DefinedType, Enum, Array,
     Map, Fixed, LogicalType,
 )
+from avro2py.utils import VERSION
 
 PRIMITIVE_TYPE_MAPPINGS = {
     Primitives.NULL: 'None',
@@ -498,7 +499,7 @@ def populate_namespaces(schemas: List[Record]) -> Generator[Tuple[str, ast.Modul
             node = rewriter.visit(namespace.node)
 
         module_docstring = ast.Expr(value=ast.Str(
-            s=f'Schema definitions for `{namespace_name}` namespace. Generated by avro2py v.0.0.1.'
+            s=f'Schema definitions for `{namespace_name}` namespace. Generated by avro2py v.{VERSION}.'
         ))
         yield namespace_name, ast.Module(
             body=[module_docstring] + consolidate_imports(namespace.imports) + node.body,
